==> senior_design_system-6.0.0.tar.gz: example/lib/pages/timeline.example.dart <==
import 'package:flutter/material.dart';

import 'package:provider/provider.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';
import 'package:senior_design_system/senior_design_system.dart';

import '../widgets/page_wrapper.dart';
import '../widgets/panel.dart';

class TimelineExample extends StatelessWidget {
  const TimelineExample({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return PageWrapper(
      title: 'Timeline',
      child: SingleChildScrollView(
        child: Consumer<ThemeRepository>(
          builder: (context, repository, child) => Column(
            children: [
              Panel(
                title: 'Non-minimizable',
                child: Timeline(
                  children: [
                    Column(
                      mainAxisAlignment: MainAxisAlignment.center,
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: [
                        SeniorText.body('Status atual'),
                        SeniorText.small('23/03/2022 - 15h56'),
                      ],
                    ),
                    Column(
                      mainAxisAlignment: MainAxisAlignment.center,
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: [
                        SeniorText.body('Status atual'),
                        SeniorText.small('23/03/2022 - 15h56'),
                      ],
                    ),
                    Column(
                      mainAxisAlignment: MainAxisAlignment.center,
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: [
                        SeniorText.body('Status atual'),
                        SeniorText.small('23/03/2022 - 15h56'),
                      ],
                    ),
                    Column(
                      mainAxisAlignment: MainAxisAlignment.center,
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: [
                        SeniorText.body('Status atual'),
                        SeniorText.small('23/03/2022 - 15h56'),
                      ],
                    ),
                    Column(
                      mainAxisAlignment: MainAxisAlignment.center,
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: [
                        SeniorText.body('Status atual'),
                        SeniorText.small('23/03/2022 - 15h56'),
                      ],
                    ),
                  ],
                  indicators: [
                    const SeniorTimelineIndicator(
                      color: SeniorColors.secondaryColor700,
                      iconId: FontAwesomeIcons.hourglass,
                      iconColor: SeniorColors.secondaryColor100,
                    ),
                    const SeniorTimelineIndicator(
                      color: SeniorColors.manchesterColorGreen600,
                      iconId: FontAwesomeIcons.check,
                      iconColor: SeniorColors.secondaryColor100,
                    ),
                    const SeniorTimelineIndicator(
                      color: SeniorColors.manchesterColorYellow,
                      iconId: FontAwesomeIcons.exclamation,
                      iconColor: SeniorColors.neutralColor900,
                    ),
                    const SeniorTimelineIndicator(
                      color: SeniorColors.manchesterColorGreen600,
                      darkColor: SeniorColors.manchesterColorGreen500,
                      textId: '59',
                      iconColor: SeniorColors.secondaryColor100,
                    ),
                    const SeniorTimelineIndicator(
                      color: SeniorColors.manchesterColorRed600,
                      darkColor: SeniorColors.manchesterColorRed500,
                      iconId: FontAwesomeIcons.xmark,
                      iconColor: SeniorColors.secondaryColor100,
                    ),
                  ],
                ),
              ),
              Panel(
                title: 'Minimizable',
                child: Timeline(
                  minimizeable: true,
                  children: [
                    Column(
                      mainAxisAlignment: MainAxisAlignment.center,
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: [
                        SeniorText.body('Status atual'),
                        SeniorText.small('23/03/2022 - 15h56'),
                      ],
                    ),
                    Column(
                      mainAxisAlignment: MainAxisAlignment.center,
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: [
                        SeniorText.body('Status atual'),
                        SeniorText.small('23/03/2022 - 15h56'),
                      ],
                    ),
                    Column(
                      mainAxisAlignment: MainAxisAlignment.center,
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: [
                        SeniorText.body('Status atual'),
                        SeniorText.small('23/03/2022 - 15h56'),
                      ],
                    ),
                    Column(
                      mainAxisAlignment: MainAxisAlignment.center,
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: [
                        SeniorText.body('Status atual'),
                        SeniorText.small('23/03/2022 - 15h56'),
                      ],
                    ),
                    Column(
                      mainAxisAlignment: MainAxisAlignment.center,
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: [
                        SeniorText.body('Status atual'),
                        SeniorText.small('23/03/2022 - 15h56'),
                      ],
                    ),
                  ],
                  indicators: [
                    const SeniorTimelineIndicator(
                      color: SeniorColors.secondaryColor700,
                      iconId: FontAwesomeIcons.hourglass,
                      iconColor: SeniorColors.secondaryColor100,
                    ),
                    const SeniorTimelineIndicator(
                      color: SeniorColors.manchesterColorGreen600,
                      iconId: FontAwesomeIcons.check,
                      iconColor: SeniorColors.secondaryColor100,
                    ),
                    const SeniorTimelineIndicator(
                      color: SeniorColors.manchesterColorYellow,
                      iconId: FontAwesomeIcons.exclamation,
                      iconColor: SeniorColors.neutralColor900,
                    ),
                    const SeniorTimelineIndicator(
                      color: SeniorColors.manchesterColorGreen600,
                      textId: '199',
                      iconColor: SeniorColors.secondaryColor100,
                    ),
                    const SeniorTimelineIndicator(
                      color: SeniorColors.manchesterColorRed600,
                      iconId: FontAwesomeIcons.xmark,
                      iconColor: SeniorColors.secondaryColor100,
                    ),
                  ],
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}

==> senior_design_system-7.0.4.tar.gz: example/lib/pages/timeline.example.dart <==
import 'package:flutter/material.dart';

import 'package:provider/provider.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';
import 'package:senior_design_system/senior_design_system.dart';

import '../widgets/page_wrapper.dart';
import '../widgets/panel.dart';

class TimelineExample extends StatelessWidget {
  const TimelineExample({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return PageWrapper(
      title: 'Timeline',
      child: SingleChildScrollView(
        child: Consumer<ThemeRepository>(
          builder: (context, repository, child) => Column(
            children: [
              Panel(
                title: 'Non-minimizable',
                child: Timeline(
                  children: [
                    Column(
                      mainAxisAlignment: MainAxisAlignment.center,
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: [
                        SeniorText.body('Status atual'),
                        SeniorText.small('23/03/2022 - 15h56'),
                      ],
                    ),
                    Column(
                      mainAxisAlignment: MainAxisAlignment.center,
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: [
                        SeniorText.body('Status atual'),
                        SeniorText.small('23/03/2022 - 15h56'),
                      ],
                    ),
                    Column(
                      mainAxisAlignment: MainAxisAlignment.center,
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: [
                        SeniorText.body('Status atual'),
                        SeniorText.small('23/03/2022 - 15h56'),
                      ],
                    ),
                    Column(
                      mainAxisAlignment: MainAxisAlignment.center,
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: [
                        SeniorText.body('Status atual'),
                        SeniorText.small('23/03/2022 - 15h56'),
                      ],
                    ),
                    Column(
                      mainAxisAlignment: MainAxisAlignment.center,
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: [
                        SeniorText.body('Status atual'),
                        SeniorText.small('23/03/2022 - 15h56'),
                      ],
                    ),
                  ],
                  indicators: [
                    const SeniorTimelineIndicator(
                      color: SeniorColors.grayscale70,
                      iconId: FontAwesomeIcons.hourglass,
                      iconColor: SeniorColors.grayscale10,
                    ),
                    const SeniorTimelineIndicator(
                      color: SeniorColors.manchesterColorGreen600,
                      iconId: FontAwesomeIcons.check,
                      iconColor: SeniorColors.grayscale10,
                    ),
                    const SeniorTimelineIndicator(
                      color: SeniorColors.manchesterColorYellow,
                      iconId: FontAwesomeIcons.exclamation,
                      iconColor: SeniorColors.grayscale90,
                    ),
                    const SeniorTimelineIndicator(
                      color: SeniorColors.manchesterColorGreen600,
                      darkColor: SeniorColors.manchesterColorGreen500,
                      textId: '59',
                      iconColor: SeniorColors.grayscale10,
                    ),
                    const SeniorTimelineIndicator(
                      color: SeniorColors.manchesterColorRed600,
                      darkColor: SeniorColors.manchesterColorRed500,
                      iconId: FontAwesomeIcons.xmark,
                      iconColor: SeniorColors.grayscale10,
                    ),
                  ],
                ),
              ),
              Panel(
                title: 'Minimizable',
                child: Timeline(
                  minimizeable: true,
                  children: [
                    Column(
                      mainAxisAlignment: MainAxisAlignment.center,
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: [
                        SeniorText.body('Status atual'),
                        SeniorText.small('23/03/2022 - 15h56'),
                      ],
                    ),
                    Column(
                      mainAxisAlignment: MainAxisAlignment.center,
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: [
                        SeniorText.body('Status atual'),
                        SeniorText.small('23/03/2022 - 15h56'),
                      ],
                    ),
                    Column(
                      mainAxisAlignment: MainAxisAlignment.center,
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: [
                        SeniorText.body('Status atual'),
                        SeniorText.small('23/03/2022 - 15h56'),
                      ],
                    ),
                    Column(
                      mainAxisAlignment: MainAxisAlignment.center,
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: [
                        SeniorText.body('Status atual'),
                        SeniorText.small('23/03/2022 - 15h56'),
                      ],
                    ),
                    Column(
                      mainAxisAlignment: MainAxisAlignment.center,
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: [
                        SeniorText.body('Status atual'),
                        SeniorText.small('23/03/2022 - 15h56'),
                      ],
                    ),
                  ],
                  indicators: [
                    const SeniorTimelineIndicator(
                      color: SeniorColors.grayscale70,
                      iconId: FontAwesomeIcons.hourglass,
                      iconColor: SeniorColors.grayscale10,
                    ),
                    const SeniorTimelineIndicator(
                      color: SeniorColors.manchesterColorGreen600,
                      iconId: FontAwesomeIcons.check,
                      iconColor: SeniorColors.grayscale10,
                    ),
                    const SeniorTimelineIndicator(
                      color: SeniorColors.manchesterColorYellow,
                      iconId: FontAwesomeIcons.exclamation,
                      iconColor: SeniorColors.grayscale90,
                    ),
                    const SeniorTimelineIndicator(
                      color: SeniorColors.manchesterColorGreen600,
                      textId: '199',
                      iconColor: SeniorColors.grayscale10,
                    ),
                    const SeniorTimelineIndicator(
                      color: SeniorColors.manchesterColorRed600,
                      iconId: FontAwesomeIcons.xmark,
                      iconColor: SeniorColors.grayscale10,
                    ),
                  ],
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
